import 'package:frideos/frideos.dart';
import 'package:shared_preferences/shared_preferences.dart';
import 'my_theme.dart';

class AppState extends AppStateModel {
  factory AppState() => _singletonAppState;

  static final AppState _singletonAppState = AppState._internal();

  AppState._internal() {
    print('-------APP STATE INIT--------');
    _createThemes(themes);
  }

  // THEMES
  final themes = List<MyTheme>();
  final currentTheme = StreamedValue<MyTheme>();

  MyTheme get myTheme => currentTheme.value;

  void _createThemes(List<MyTheme> themes) {
    themes.addAll([
      AppTheme.defaultLight,
    ]);
  }

  @override
  Future<void> init() async {
    var prefs = await SharedPreferences.getInstance();

    final String lastTheme = prefs.getString('appTheme');

    if (lastTheme != null) {
      currentTheme.value = themes.firstWhere(
            (theme) => theme.name == lastTheme,
        orElse: () => themes[0],
      );
    } else {
      currentTheme.value = themes[0];
    }
  }

  @override
  void dispose() {
    print('-------APP STATE DISPOSE-------');
  }
}